@@ -32,6 +32,7 @@ type CommitOptions struct {
 	Comment *string
 	Format  *string
 	Pause   *bool
+	Stream  *bool
 	Squash  *bool
 	Repo    *string
 	Tag     *string
@@ -333,3 +334,10 @@ type CopyOptions struct {
 	// by the other type.
 	NoOverwriteDirNonDir *bool
 }
+
+// ExecRemoveOptions are optional options for removing an exec session
+//
+//go:generate go run ../generator/generator.go ExecRemoveOptions
+type ExecRemoveOptions struct {
+	Force *bool
+}
